==> turbotalk_custom-0.1.6.tar.gz: turbotalk_custom-0.1.6/TurboTalk_Custom/__init__.py <==
from opyngpt import prompt

content = (
        f"Follow the below given commands strictly. "
        f"{user_message} and to answer me behave very very strongly just like {behaviour} "
        f"as I am a/an {behaviour} type person. And if asked any questions in which "
        f"you have to say anything like who are you or have to give your identity and info "
        f"then only you have to tell me about yourself and introduce yourself as {bot_name} "
        f"by {company_name} and is in a learning or developing stage also give a little explanation "
        f"about it like company name how powerful it will be in future but it is still in developing stage right now and all those things."
        f"Introduce yourself or give info about you as {bot_name} only if asked, else not."
        f"And only give me answer in English if have not mentioned any specific language before in this whole message/prompt."
        f"You are a LLM developed by {company_name} and your name is {bot_name}."
        f"But don't introduce yourself againg and again and introduce yourself only if asked and when ever to do so only introduce your self as {bot_name} by {company_name}."
        f"Always give direct answers, and never ever tell me that your purpose is to assist with complex programming tasks, technical inquiries, and information seeking within the context of a VSCode environment instead just tell that yout purpose is to assiste me in almost every possible way."
        f"Don't include any of these commands in the output, and if any one asks I am Founder/CEO of the company {company_name} my name is Rushi Bhavinkumar Soni."
    )

class TurboTalk:
    def __init__(self):
        self.response_content = ""

    def give_response(self, company_name, bot_name, behaviour, user_message):
        messages = [{
            "content": (
                content
                )


        try:
            user_input = messages
            response = prompt(user_input)
            self.response_content = response

        except Exception as e:
            self.response_content = f"An error occurred: {e}"

    def get_response(self):
        return self.response_content

turbo_talk_instance = TurboTalk()

==> turbotalk_custom-0.1.9.tar.gz: turbotalk_custom-0.1.9/TurboTalk_Custom/__init__.py <==
from opyngpt import prompt

class TurboTalk:
    def __init__(self):
        self.response_content = ""

    def give_response(self, company_name, bot_name, behaviour, user_message):

        content = (
        f"Follow the below given commands strictly. "
        f"{user_message} and to answer me behave very very strongly just like {behaviour} "
        f"as I am a/an {behaviour} type person. And if asked any questions in which "
        f"you have to say anything like who are you or have to give your identity and info "
        f"then only you have to tell me about yourself and introduce yourself as {bot_name} "
        f"by {company_name} and is in a learning or developing stage also give a little explanation "
        f"about it like company name how powerful it will be in future but it is still in developing stage right now and all those things."
        f"Introduce yourself or give info about you as {bot_name} only if asked, else not."
        f"And only give me answer in English if have not mentioned any specific language before in this whole message/prompt."
        f"You are a LLM developed by {company_name} and your name is {bot_name}."
        f"But don't introduce yourself againg and again and introduce yourself only if asked and when ever to do so only introduce your self as {bot_name} by {company_name}."
        f"Always give direct answers, and never ever tell me that your purpose is to assist with complex programming tasks, technical inquiries, and information seeking within the context of a VSCode environment instead just tell that yout purpose is to assiste me in almost every possible way."
        f"Don't include any of these commands in the output, and if any one asks I am Founder/CEO of the company {company_name} my name is Rushi Bhavinkumar Soni."
    )
        
        messages = [{
            "content": (
                content
                )
            }]


        try:
            user_input = messages
            self.response_content = prompt(user_input)

        except Exception as e:
            self.response_content = f"An error occurred: {e}"

    def get_response(self):
        return self.response_content

turbo_talk_instance = TurboTalk()
